@@ -40,7 +40,7 @@ function openApplicationMime(mime) {
 function openApplicationList(props) {
     var page = window.stack.push(applicationListComp, props)
     if (props.search === "")
-        page.clearSearch()
+        page.clearSearch();
 }
 
 function openCategory(cat, search) {
@@ -58,13 +58,13 @@ function openReviews(model) {
 }
 
 function openExtends(ext) {
-    window.stack.push(applicationListComp, { extend: ext, title: i18n("Extensions...") })
+    window.stack.push(applicationListComp, { extending: ext, title: i18n("Extensions...") })
 }
 
 function openHome() {
     if (window.globalDrawer.currentSubMenu)
         window.globalDrawer.resetMenu();
     clearStack()
-    window.globalDrawer.clearSearch();
-    window.stack.push(topBrowsingComp)
+    var page = window.stack.push(topBrowsingComp)
+    page.clearSearch()
 }
