@@ -47,6 +47,7 @@
 #include <QDebug>
 #include <QDir>
 #include <QFile>
+#include <QFileInfo>
 #include <QFutureWatcher>
 #include <QMessageBox>
 #include <QSettings>
@@ -58,7 +59,7 @@
 
 #include <glib.h>
 
-MUON_BACKEND_PLUGIN(FlatpakBackend)
+DISCOVER_BACKEND_PLUGIN(FlatpakBackend)
 
 static QString idForInstalledRef(FlatpakInstallation *installation, FlatpakInstalledRef *ref)
 {
@@ -78,6 +79,7 @@ FlatpakBackend::FlatpakBackend(QObject* parent)
     , m_updater(new StandardBackendUpdater(this))
     , m_reviews(AppStreamIntegration::global()->reviews())
     , m_fetching(false)
+    , m_refreshAppstreamMetadataJobs(0)
     , m_threadPool(new QThreadPool(this))
 {
     g_autoptr(GError) error = nullptr;
@@ -89,9 +91,7 @@ FlatpakBackend::FlatpakBackend(QObject* parent)
     if (!setupFlatpakInstallations(&error)) {
         qWarning() << "Failed to setup flatpak installations:" << error->message;
     } else {
-        reloadPackageList();
-
-        checkForUpdates();
+        loadAppsFromAppstreamData();
 
         m_sources = new FlatpakSourcesBackend(m_installations, this);
         SourcesModel::global()->addSourcesBackend(m_sources);
@@ -530,6 +530,22 @@ private:
     FlatpakRemote* m_remote;
 };
 
+void FlatpakBackend::finishInitialization()
+{
+    loadInstalledApps();
+    checkForUpdates();
+}
+
+void FlatpakBackend::loadAppsFromAppstreamData()
+{
+    for (auto installation : qAsConst(m_installations)) {
+        // Load applications from appstream metadata
+        if (!loadAppsFromAppstreamData(installation)) {
+            qWarning() << "Failed to load packages from appstream data from installation" << installation;
+        }
+    }
+}
+
 bool FlatpakBackend::loadAppsFromAppstreamData(FlatpakInstallation *flatpakInstallation)
 {
     Q_ASSERT(flatpakInstallation);
@@ -539,6 +555,8 @@ bool FlatpakBackend::loadAppsFromAppstreamData(FlatpakInstallation *flatpakInsta
         return false;
     }
 
+    m_refreshAppstreamMetadataJobs += remotes->len;
+
     for (uint i = 0; i < remotes->len; i++) {
         FlatpakRemote *remote = FLATPAK_REMOTE(g_ptr_array_index(remotes, i));
         g_autoptr(GFile) fileTimestamp = flatpak_remote_get_appstream_timestamp(remote, nullptr);
@@ -557,6 +575,8 @@ bool FlatpakBackend::loadAppsFromAppstreamData(FlatpakInstallation *flatpakInsta
 
 void FlatpakBackend::integrateRemote(FlatpakInstallation *flatpakInstallation, FlatpakRemote *remote)
 {
+    m_refreshAppstreamMetadataJobs--;
+
     FlatpakSource source(remote);
     if (!source.isEnabled() || flatpak_remote_get_noenumerate(remote)) {
         return;
@@ -570,23 +590,42 @@ void FlatpakBackend::integrateRemote(FlatpakInstallation *flatpakInstallation, F
         return;
     }
 
-    AppStream::Metadata metadata;
-    metadata.setFormatStyle(AppStream::Metadata::FormatStyleCollection);
-    AppStream::Metadata::MetadataError error = metadata.parseFile(appDirFileName, AppStream::Metadata::FormatKindXml);
-    if (error != AppStream::Metadata::MetadataErrorNoError) {
-        qWarning() << "Failed to parse appstream metadata: " << error;
-        return;
-    }
+    auto fw = new QFutureWatcher<QList<AppStream::Component>>(this);
+    fw->setFuture(QtConcurrent::run(&m_threadPool, [appDirFileName]() -> QList<AppStream::Component> {
+        AppStream::Metadata metadata;
+        metadata.setFormatStyle(AppStream::Metadata::FormatStyleCollection);
+        AppStream::Metadata::MetadataError error = metadata.parseFile(appDirFileName, AppStream::Metadata::FormatKindXml);
+        if (error != AppStream::Metadata::MetadataErrorNoError) {
+            qWarning() << "Failed to parse appstream metadata: " << error;
+            return {};
+        }
 
-    setFetching(true);
-    QList<AppStream::Component> components = metadata.components();
-    foreach (const AppStream::Component& appstreamComponent, components) {
-        FlatpakResource *resource = new FlatpakResource(appstreamComponent, flatpakInstallation, this);
-        resource->setIconPath(appstreamIconsPath);
-        resource->setOrigin(source.name());
-        addResource(resource);
+        return metadata.components();
+    }));
+    const auto sourceName = source.name();
+    connect(fw, &QFutureWatcher<QList<AppStream::Component>>::finished, this, [this, fw, flatpakInstallation, appstreamIconsPath, sourceName]() {
+        const auto components = fw->result();
+        foreach (const AppStream::Component& appstreamComponent, components) {
+            FlatpakResource *resource = new FlatpakResource(appstreamComponent, flatpakInstallation, this);
+            resource->setIconPath(appstreamIconsPath);
+            resource->setOrigin(sourceName);
+            addResource(resource);
+        }
+        if (!m_refreshAppstreamMetadataJobs) {
+            finishInitialization();
+        }
+        fw->deleteLater();
+    });
+}
+
+void FlatpakBackend::loadInstalledApps()
+{
+    for (auto installation : qAsConst(m_installations)) {
+        // Load installed applications and update existing resources with info from installed application
+        if (!loadInstalledApps(installation)) {
+            qWarning() << "Failed to load installed packages from installation" << installation;
+        }
     }
-    setFetching(false);
 }
 
 bool FlatpakBackend::loadInstalledApps(FlatpakInstallation *flatpakInstallation)
@@ -603,26 +642,18 @@ bool FlatpakBackend::loadInstalledApps(FlatpakInstallation *flatpakInstallation)
     const QString pathExports = FlatpakResource::installationPath(flatpakInstallation) + QLatin1String("/exports/");
     const QString pathApps = pathExports + QLatin1String("share/applications/");
 
-
     for (uint i = 0; i < refs->len; i++) {
         FlatpakInstalledRef *ref = FLATPAK_INSTALLED_REF(g_ptr_array_index(refs, i));
 
-        const auto name = QLatin1String(flatpak_ref_get_name(FLATPAK_REF(ref)));
-
-        g_autoptr(GError) gerror = nullptr;
-        auto md = flatpak_installed_ref_load_metadata(ref, m_cancellable, &gerror);
-        if (!md) {
-            qDebug() << "error message" << gerror->message;
+        if (flatpak_ref_get_kind(FLATPAK_REF(ref)) == FLATPAK_REF_KIND_RUNTIME) {
             continue;
         }
 
-        gsize len = 0;
-        gconstpointer data = g_bytes_get_data(md, &len);
-
+        const auto name = QLatin1String(flatpak_ref_get_name(FLATPAK_REF(ref)));
         AppStream::Metadata metadata;
-        AppStream::Metadata::MetadataError error = metadata.parseDesktopData(QString::fromUtf8((const char*) data, len), name);
+        const QString fnDesktop = pathApps + name + QLatin1String(".desktop");
+        AppStream::Metadata::MetadataError error = metadata.parseFile(fnDesktop, AppStream::Metadata::FormatKindDesktopEntry);
         if (error != AppStream::Metadata::MetadataErrorNoError) {
-            const QString fnDesktop = pathApps + name + QLatin1String(".desktop");
             qWarning() << "Failed to parse appstream metadata: " << error << fnDesktop;
             continue;
         }
@@ -797,29 +828,13 @@ private:
 void FlatpakBackend::refreshAppstreamMetadata(FlatpakInstallation *installation, FlatpakRemote *remote)
 {
     FlatpakRefreshAppstreamMetadataJob *job = new FlatpakRefreshAppstreamMetadataJob(installation, remote);
+    connect(job, &FlatpakRefreshAppstreamMetadataJob::jobRefreshAppstreamMetadataFailed, this, [this] () {
+        m_refreshAppstreamMetadataJobs--;
+    });
     connect(job, &FlatpakRefreshAppstreamMetadataJob::jobRefreshAppstreamMetadataFinished, this, &FlatpakBackend::integrateRemote);
     job->start();
 }
 
-void FlatpakBackend::reloadPackageList()
-{
-    setFetching(true);
-
-    for (auto installation : qAsConst(m_installations)) {
-        // Load applications from appstream metadata
-        if (!loadAppsFromAppstreamData(installation)) {
-            qWarning() << "Failed to load packages from appstream data from installation" << installation;
-        }
-
-        // Load installed applications and update existing resources with info from installed application
-        if (!loadInstalledApps(installation)) {
-            qWarning() << "Failed to load installed packages from installation" << installation;
-        }
-    }
-
-    setFetching(false);
-}
-
 bool FlatpakBackend::setupFlatpakInstallations(GError **error)
 {
     GPtrArray *installations = flatpak_get_system_installations(m_cancellable, error);
