@@ -48,7 +48,6 @@ public:
     AbstractReviewsBackend* reviewsBackend() const override;
     AbstractBackendUpdater* backendUpdater() const override;
     bool isFetching() const override;
-    QList<QAction*> messageActions() const override { return QList<QAction*>(); }
     ResultsStream* search(const AbstractResourcesBackend::Filters & filter) override;
     ResultsStream* findResourceByPackageName(const QUrl & search) override;
 
@@ -96,6 +95,7 @@ private:
     QStringList m_extends;
     QStringList m_categories;
     QVector<Category*> m_rootCategories;
+    QString m_displayName;
 };
 
 #endif // KNSBACKEND_H
