@@ -26,6 +26,7 @@
 #include "AppPackageKitResource.h"
 #include "PKTransaction.h"
 #include "LocalFilePKResource.h"
+#include "TransactionSet.h"
 #include <resources/AbstractResource.h>
 #include <resources/StandardBackendUpdater.h>
 #include <resources/SourcesModel.h>
@@ -42,7 +43,6 @@
 #include <PackageKit/Daemon>
 #include <PackageKit/Details>
 
-#include <KDesktopFile>
 #include <KLocalizedString>
 #include <QAction>
 #include <QMimeDatabase>
@@ -50,9 +50,9 @@
 #include "utils.h"
 #include "config-paths.h"
 
-MUON_BACKEND_PLUGIN(PackageKitBackend)
+DISCOVER_BACKEND_PLUGIN(PackageKitBackend)
 
-static QString locateService(const QString &filename)
+QString PackageKitBackend::locateService(const QString &filename)
 {
     return QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("applications/")+filename);
 }
@@ -74,16 +74,6 @@ PackageKitBackend::PackageKitBackend(QObject* parent)
     m_delayedDetailsFetch.setInterval(0);
     connect(&m_delayedDetailsFetch, &QTimer::timeout, this, &PackageKitBackend::performDetailsFetch);
 
-    // Kubuntu-based
-    auto service = locateService(QStringLiteral("software-properties-kde.desktop"));
-    if (!service.isEmpty())
-        m_messageActions += createActionForService(service);
-
-    // openSUSE-based
-    service = locateService(QStringLiteral("YaST2/sw_source.desktop"));
-    if (!service.isEmpty())
-        m_messageActions += createActionForService(service);
-
     connect(PackageKit::Daemon::global(), &PackageKit::Daemon::updatesChanged, this, &PackageKitBackend::fetchUpdates);
     connect(PackageKit::Daemon::global(), &PackageKit::Daemon::isRunningChanged, this, &PackageKitBackend::checkDaemonRunning);
     connect(m_reviews.data(), &OdrsReviewsBackend::ratingsReady, this, &AbstractResourcesBackend::emitRatingsReady);
@@ -112,20 +102,6 @@ void PackageKitBackend::delayedInit()
     }
 }
 
-QAction* PackageKitBackend::createActionForService(const QString &servicePath)
-{
-    QAction* action = new QAction(this);
-    KDesktopFile parser(servicePath);
-    action->setIcon(QIcon::fromTheme(parser.readIcon()));
-    action->setText(parser.readName());
-    connect(action, &QAction::triggered, action, [servicePath, this](){
-        bool b = QProcess::startDetached(QStringLiteral(CMAKE_INSTALL_FULL_LIBEXECDIR_KF5 "/discover/runservice"), {servicePath});
-        if (!b)
-            qWarning() << "Could not start" << servicePath;
-    });
-    return action;
-}
-
 bool PackageKitBackend::isFetching() const
 {
     return m_isFetching;
@@ -212,38 +188,6 @@ AppPackageKitResource* PackageKitBackend::addComponent(const AppStream::Componen
     return res;
 }
 
-class TransactionSet : public QObject
-{
-    Q_OBJECT
-    public:
-        TransactionSet(const QVector<PackageKit::Transaction*> &transactions)
-            : m_transactions(transactions)
-        {
-            foreach(PackageKit::Transaction* t, transactions) {
-                connect(t, &PackageKit::Transaction::finished, this, &TransactionSet::transactionFinished);
-            }
-        }
-
-        void transactionFinished(PackageKit::Transaction::Exit exit) {
-            PackageKit::Transaction* t = qobject_cast<PackageKit::Transaction*>(sender());
-            if (exit != PackageKit::Transaction::ExitSuccess) {
-                qWarning() << "failed" << exit << t;
-            }
-
-            m_transactions.removeAll(t);
-            if (m_transactions.isEmpty()) {
-                Q_EMIT allFinished();
-            }
-        }
-
-    Q_SIGNALS:
-        void allFinished();
-
-    private:
-        QVector<PackageKit::Transaction*> m_transactions;
-
-};
-
 void PackageKitBackend::clearPackages(const QStringList& packageNames)
 {
     const auto resources = resourcesByPackageNames<QVector<AbstractResource*>>(packageNames);
@@ -277,6 +221,7 @@ void PackageKitBackend::fetchUpdates()
     connect(tUpdates, &PackageKit::Transaction::package, this, &PackageKitBackend::addPackageToUpdate);
     connect(tUpdates, &PackageKit::Transaction::errorCode, this, &PackageKitBackend::transactionError);
     m_updatesPackageId.clear();
+    m_hasSecurityUpdates = false;
 
     m_updater->setProgressing(true);
 }
@@ -309,7 +254,7 @@ void PackageKitBackend::getPackagesFinished()
     for(auto it = m_packages.packages.cbegin(); it != m_packages.packages.cend(); ++it) {
         auto pkr = qobject_cast<PackageKitResource*>(it.value());
         if (pkr->packages().isEmpty()) {
-            qWarning() << "Failed to find package for" << it.key();
+//             qWarning() << "Failed to find package for" << it.key();
             m_packagesToDelete += pkr;
         }
     }
@@ -392,7 +337,6 @@ void PackageKitBackend::refreshDatabase()
         connect(m_refresher.data(), &PackageKit::Transaction::finished, this, [this]() {
             reloadPackageList();
             acquireFetching(false);
-            delete m_refresher;
         });
     } else {
         qWarning() << "already resetting";
@@ -403,6 +347,9 @@ ResultsStream* PackageKitBackend::search(const AbstractResourcesBackend::Filters
 {
     if (!filter.resourceUrl.isEmpty()) {
         return findResourceByPackageName(filter.resourceUrl);
+    } else if (!filter.extends.isEmpty()) {
+        const auto ext = kTransform<QVector<AbstractResource*>>(m_packages.extendedBy[filter.extends], [](AppPackageKitResource* a){ return a; });
+        return new ResultsStream(QStringLiteral("PackageKitStream-extends"), ext);
     } else if (filter.search.isEmpty()) {
         return new ResultsStream(QStringLiteral("PackageKitStream-all"), kFilter<QVector<AbstractResource*>>(m_packages.packages, [](AbstractResource* res) { return !res->isTechnical(); }));
     } else {
@@ -448,6 +395,11 @@ ResultsStream * PackageKitBackend::findResourceByPackageName(const QUrl& url)
     return new ResultsStream(QStringLiteral("PackageKitStream-url"), pkg ? QVector<AbstractResource*>{pkg} : QVector<AbstractResource*>{});
 }
 
+bool PackageKitBackend::hasSecurityUpdates() const
+{
+    return m_hasSecurityUpdates;
+}
+
 int PackageKitBackend::updatesCount() const
 {
     return m_updatesPackageId.count();
@@ -509,10 +461,15 @@ QSet<AbstractResource*> PackageKitBackend::upgradeablePackages() const
 
 void PackageKitBackend::addPackageToUpdate(PackageKit::Transaction::Info info, const QString& packageId, const QString& summary)
 {
-    if (info != PackageKit::Transaction::InfoBlocked) {
-        m_updatesPackageId += packageId;
-        addPackage(info, packageId, summary, true);
+    if (info == PackageKit::Transaction::InfoBlocked) {
+        return;
     }
+
+    if (info == PackageKit::Transaction::InfoSecurity)
+        m_hasSecurityUpdates = true;
+
+    m_updatesPackageId += packageId;
+    addPackage(info, packageId, summary, true);
 }
 
 void PackageKitBackend::getUpdatesFinished(PackageKit::Transaction::Exit, uint)
@@ -581,11 +538,6 @@ AbstractBackendUpdater* PackageKitBackend::backendUpdater() const
     return m_updater;
 }
 
-QList<QAction*> PackageKitBackend::messageActions() const
-{
-    return m_messageActions;
-}
-
 QVector<AppPackageKitResource*> PackageKitBackend::extendedBy(const QString& id) const
 {
     return m_packages.extendedBy[id];
