@@ -50,6 +50,7 @@ class DISCOVERCOMMON_EXPORT PackageKitBackend : public AbstractResourcesBackend
         ResultsStream* search(const AbstractResourcesBackend::Filters & search) override;
         ResultsStream* findResourceByPackageName(const QUrl& search) override;
         int updatesCount() const override;
+        bool hasSecurityUpdates() const override;
 
         Transaction* installApplication(AbstractResource* app) override;
         Transaction* installApplication(AbstractResource* app, const AddonList& addons) override;
@@ -57,7 +58,6 @@ class DISCOVERCOMMON_EXPORT PackageKitBackend : public AbstractResourcesBackend
         bool isValid() const override { return true; }
         QSet<AbstractResource*> upgradeablePackages() const;
         bool isFetching() const override;
-        QList<QAction*> messageActions() const override;
 
         bool isPackageNameUpgradeable(const PackageKitResource* res) const;
         QString upgradeablePackageId(const PackageKitResource* res) const;
@@ -72,6 +72,7 @@ class DISCOVERCOMMON_EXPORT PackageKitBackend : public AbstractResourcesBackend
         QString displayName() const override;
 
         bool hasApplications() const override { return true; }
+        static QString locateService(const QString &filename);
 
     public Q_SLOTS:
         void reloadPackageList();
@@ -100,16 +101,15 @@ class DISCOVERCOMMON_EXPORT PackageKitBackend : public AbstractResourcesBackend
         void includePackagesToAdd();
         void performDetailsFetch();
         AppPackageKitResource* addComponent(const AppStream::Component& component, const QStringList& pkgNames);
-        QAction* createActionForService(const QString &filename);
 
         AppStream::Pool m_appdata;
         PackageKitUpdater* m_updater;
         QPointer<PackageKit::Transaction> m_refresher;
         int m_isFetching;
         QSet<QString> m_updatesPackageId;
+        bool m_hasSecurityUpdates = false;
         QSet<PackageKitResource*> m_packagesToAdd;
         QSet<PackageKitResource*> m_packagesToDelete;
-        QList<QAction*> m_messageActions;
 
         struct Packages {
             QHash<QString, AbstractResource*> packages;
