@@ -31,6 +31,7 @@ PackageKitResource::PackageKitResource(QString packageName, QString summary, Pac
     : AbstractResource(parent)
     , m_summary(std::move(summary))
     , m_name(std::move(packageName))
+    , m_dependenciesCount(0)
 {
     setObjectName(m_name);
 }
@@ -168,6 +169,18 @@ void PackageKitResource::fetchDetails()
     m_details.insert(QStringLiteral("fetching"), true);//we add an entry so it's not re-fetched.
 
     backend()->fetchDetails(pkgid);
+
+    auto trans = PackageKit::Daemon::installPackages({ pkgid }, PackageKit::Transaction::TransactionFlagSimulate);
+    connect(trans, &PackageKit::Transaction::package, this, [trans](PackageKit::Transaction::Info /*info*/, const QString &/*packageID*/, const QString &/*summary*/) {
+        trans->setProperty("dependencies", trans->property("dependencies").toUInt() + 1);
+    });
+    connect(trans, &PackageKit::Transaction::finished, this, [this, trans](PackageKit::Transaction::Exit /*status*/) {
+        auto deps = trans->property("dependencies").toUInt();
+        if (deps != m_dependenciesCount) {
+            m_dependenciesCount = deps;
+            Q_EMIT sizeChanged();
+        }
+    });
 }
 
 void PackageKitResource::failedFetchingDetails(PackageKit::Transaction::Error, const QString& msg)
@@ -203,13 +216,14 @@ static void addIfNotEmpty(const QString& title, const QString& content, QString&
         where += QStringLiteral("<p><b>") + title + QStringLiteral("</b>&nbsp;") + QString(content).replace(QStringLiteral("\n"), QStringLiteral("<br />")) + QStringLiteral("</p>");
 }
 
-QString PackageKitResource::joinPackages(const QStringList& pkgids)
+QString PackageKitResource::joinPackages(const QStringList& pkgids, const QString &_sep)
 {
     QStringList ret;
     foreach(const QString& pkgid, pkgids) {
         ret += i18nc("package-name (version)", "%1 (%2)", PackageKit::Daemon::packageName(pkgid), PackageKit::Daemon::packageVersion(pkgid));
     }
-    return ret.join(i18nc("comma separating package names", ", "));
+    const QString sep = _sep.isEmpty() ? i18nc("comma separating package names", ", ") : _sep;
+    return ret.join(sep);
 }
 
 static QStringList urlToLinks(const QStringList& urls)
@@ -228,7 +242,6 @@ void PackageKitResource::updateDetail(const QString& /*packageID*/, const QStrin
     addIfNotEmpty(i18n("Reason:"), updateText, info);
     addIfNotEmpty(i18n("Obsoletes:"), joinPackages(obsoletes), info);
     addIfNotEmpty(i18n("Updates:"), joinPackages(updates), info);
-    addIfNotEmpty(i18n("Change Log:"), changelog, info);
     addIfNotEmpty(i18n("Update State:"), PackageKitMessages::updateStateMessage(state), info);
     addIfNotEmpty(i18n("Restart:"), PackageKitMessages::restartMessage(restart), info);
 
@@ -243,3 +256,10 @@ PackageKitBackend* PackageKitResource::backend() const
     return qobject_cast<PackageKitBackend*>(parent());
 }
 
+QString PackageKitResource::sizeDescription()
+{
+    if (m_dependenciesCount == 0)
+        return AbstractResource::sizeDescription();
+    else
+        return i18np("%2 (plus %1 dependency)", "%2 (plus %1 dependencies)", m_dependenciesCount, AbstractResource::sizeDescription());
+}
