@@ -61,11 +61,13 @@ class PackageKitResource : public AbstractResource
 
         PackageKitBackend* backend() const;
 
-        static QString joinPackages(const QStringList& pkgids);
+        static QString joinPackages(const QStringList& pkgids, const QString &_sep = {});
 
         void invokeApplication() const override {}
         bool canExecute() const override { return false; }
 
+        QString sizeDescription() override;
+
     public Q_SLOTS:
         void addPackageId(PackageKit::Transaction::Info info, const QString &packageId, bool arch);
         void setDetails(const PackageKit::Details& details);
@@ -94,6 +96,7 @@ class PackageKitResource : public AbstractResource
         const QString m_summary;
         const QString m_name;
         PackageKit::Details m_details;
+        uint m_dependenciesCount;
 };
 
 #endif // PACKAGEKITRESOURCE_H
