@@ -31,9 +31,8 @@ class PackageKitSourcesBackend : public AbstractSourcesBackend
 {
     Q_OBJECT
     public:
-        PackageKitSourcesBackend(QObject* parent);
+        PackageKitSourcesBackend(AbstractResourcesBackend* parent);
 
-        QString name() const override;
         QString idDescription() override;
 
         bool addSource(const QString& id) override;
@@ -50,6 +49,7 @@ class PackageKitSourcesBackend : public AbstractSourcesBackend
         QStandardItem* findItemForId(const QString &id) const;
 
         PKSourcesModel* m_sources;
+        QList<QAction*> m_actions;
 };
 
 #endif // PACKAGEKITSOURCESBACKEND_H
