@@ -39,7 +39,7 @@
 
 #include "utils.h"
 
-MUON_BACKEND_PLUGIN(SnapBackend)
+DISCOVER_BACKEND_PLUGIN(SnapBackend)
 
 SnapBackend::SnapBackend(QObject* parent)
     : AbstractResourcesBackend(parent)
@@ -59,6 +59,8 @@ SnapBackend::SnapBackend(QObject* parent)
 
     //make sure we populate the installed resources first
     populate(m_client.list(), AbstractResource::Installed);
+
+    SourcesModel::global()->addBackend(this);
 }
 
 int SnapBackend::updatesCount() const
@@ -70,7 +72,9 @@ static ResultsStream* voidStream() { return new ResultsStream(QStringLiteral("Sn
 
 ResultsStream * SnapBackend::search(const AbstractResourcesBackend::Filters& filters)
 {
-    if (!filters.resourceUrl.isEmpty()) {
+    if (!filters.extends.isEmpty()) {
+        return voidStream();
+    } else if (!filters.resourceUrl.isEmpty()) {
         return findResourceByPackageName(filters.resourceUrl);
     } else if (filters.category && filters.category->isAddons()) {
         return voidStream();
@@ -84,7 +88,44 @@ ResultsStream * SnapBackend::search(const AbstractResourcesBackend::Filters& fil
 
 ResultsStream * SnapBackend::findResourceByPackageName(const QUrl& search)
 {
-    return search.scheme() == QLatin1String("snap") ? populate(m_client.find(QSnapdClient::MatchName, search.host()), AbstractResource::Installed) : voidStream();
+    return search.scheme() == QLatin1String("snap") ? populate(m_client.listOne(search.host()), AbstractResource::None) : voidStream();
+}
+
+ResultsStream * SnapBackend::populate(QSnapdListOneRequest* job, AbstractResource::State state)
+{
+    auto stream = new ResultsStream(QStringLiteral("Snap-populateOne"));
+
+    connect(job, &QSnapdFindRequest::complete, stream, [stream, this, state, job]() {
+        if (job->error()) {
+            qDebug() << "error:" << job->error() << job->errorString();
+            return;
+        }
+        QSet<SnapResource*> higher = kFilter<QSet<SnapResource*>>(m_resources, [state](AbstractResource* res){ return res->state()>=state; });
+
+        QSet<SnapResource*> resources;
+
+        QSharedPointer<QSnapdSnap> snap(job->snap());
+        const auto snapname = snap->name();
+        SnapResource* res = m_resources.value(snapname);
+        if (!res) {
+            res = new SnapResource(snap, state, this);
+            Q_ASSERT(res->packageName() == snapname);
+            resources += res;
+        } else {
+            res->setState(state);
+            higher.remove(res);
+        }
+
+        m_resources[res->packageName()] = res;
+        for(auto res: higher) {
+            res->setState(AbstractResource::None);
+        }
+
+        stream->resourcesFound({res});
+        stream->finish();
+    });
+    job->runAsync();
+    return stream;
 }
 
 template <class T>
@@ -93,6 +134,10 @@ ResultsStream* SnapBackend::populate(T* job, AbstractResource::State state)
     auto stream = new ResultsStream(QStringLiteral("Snap-populate"));
 
     connect(job, &QSnapdFindRequest::complete, stream, [stream, this, state, job]() {
+        if (job->error()) {
+            qDebug() << "error:" << job->error() << job->errorString();
+            return;
+        }
         QSet<SnapResource*> higher = kFilter<QSet<SnapResource*>>(m_resources, [state](AbstractResource* res){ return res->state()>=state; });
 
         QVector<AbstractResource*> ret;
