@@ -44,7 +44,6 @@ public:
     AbstractBackendUpdater* backendUpdater() const override;
     AbstractReviewsBackend* reviewsBackend() const override;
     bool isValid() const override { return m_valid; }
-    QList<QAction*> messageActions() const override { return {}; }
 
     Transaction* installApplication(AbstractResource* app) override;
     Transaction* installApplication(AbstractResource* app, const AddonList& addons) override;
@@ -60,6 +59,8 @@ private:
     template <class T>
     ResultsStream* populate(T* snaps, AbstractResource::State state);
 
+    ResultsStream* populate(QSnapdListOneRequest* snaps, AbstractResource::State state);
+
     QHash<QString, SnapResource*> m_resources;
     StandardBackendUpdater* m_updater;
     SnapReviewsBackend* m_reviews;
