@@ -49,7 +49,7 @@ QString SnapResource::comment()
 
 int SnapResource::size()
 {
-    return m_snap->installedSize();
+    return isInstalled() ? m_snap->installedSize() : m_snap->downloadSize();
 }
 
 QUrl SnapResource::homepage()
@@ -91,7 +91,7 @@ QString SnapResource::installedVersion() const
 
 QString SnapResource::license()
 {
-    return {};
+    return m_snap->license();
 }
 
 QString SnapResource::longDescription()
@@ -101,7 +101,7 @@ QString SnapResource::longDescription()
 
 QString SnapResource::name()
 {
-    return m_snap->name();
+    return m_snap->title().isEmpty() ? m_snap->name() : m_snap->title();
 }
 
 QString SnapResource::origin() const
@@ -157,3 +157,9 @@ bool SnapResource::isTechnical() const
 {
     return m_snap->snapType() != QLatin1String("app");
 }
+
+QUrl SnapResource::url() const
+{
+    //FIXME interim, until it has an appstreamId
+    return QUrl(QStringLiteral("snap://") + packageName());
+}
