@@ -32,6 +32,7 @@ class QAction;
 class AbstractBackendUpdater;
 class ResourcesModel;
 class QDBusInterface;
+class Transaction;
 class UpdateTransaction;
 
 class DISCOVERCOMMON_EXPORT ResourcesUpdatesModel : public QStandardItemModel
@@ -40,6 +41,7 @@ class DISCOVERCOMMON_EXPORT ResourcesUpdatesModel : public QStandardItemModel
     Q_PROPERTY(bool isProgressing READ isProgressing NOTIFY progressingChanged)
     Q_PROPERTY(QDateTime lastUpdate READ lastUpdate NOTIFY progressingChanged)
     Q_PROPERTY(qint64 secsToLastUpdate READ secsToLastUpdate NOTIFY progressingChanged)
+    Q_PROPERTY(Transaction* transaction READ transaction NOTIFY progressingChanged)
     public:
         explicit ResourcesUpdatesModel(QObject* parent = nullptr);
 
@@ -49,11 +51,13 @@ class DISCOVERCOMMON_EXPORT ResourcesUpdatesModel : public QStandardItemModel
         bool isProgressing() const;
         QList<AbstractResource*> toUpdate() const;
         QDateTime lastUpdate() const;
+        double updateSize() const;
         void addResources(const QList<AbstractResource*>& resources);
         void removeResources(const QList<AbstractResource*>& resources);
 
         qint64 secsToLastUpdate() const;
         QVector<AbstractBackendUpdater*> updaters() const { return m_updaters; }
+        Transaction* transaction() const;
 
     Q_SIGNALS:
         void downloadSpeedChanged();
