@@ -22,30 +22,60 @@
 #include <QtGlobal>
 #include <QDebug>
 #include <QAction>
+#include "resources/AbstractResourcesBackend.h"
 #include "resources/AbstractSourcesBackend.h"
 
 Q_GLOBAL_STATIC(SourcesModel, s_sources)
 
+const auto DisplayName = "DisplayName";
+
+class SourceBackendModel : public QAbstractListModel
+{
+Q_OBJECT
+public:
+    SourceBackendModel(AbstractResourcesBackend* backend)
+        : QAbstractListModel(backend), m_backend(backend)
+    {}
+
+    QVariant data(const QModelIndex & index, int role) const override {
+        if (!index.isValid()) return {};
+        switch(role) {
+            case SourcesModel::ResourcesBackend: return QVariant::fromValue<QObject*>(m_backend);
+            case SourcesModel::SourcesBackend: return QVariant::fromValue<QObject*>(m_sources);
+        }
+        return {};
+    }
+    int rowCount(const QModelIndex & parent) const override { return parent.isValid() ? 0 : 1; }
+
+    AbstractSourcesBackend* m_sources = nullptr;
+
+private:
+    AbstractResourcesBackend* m_backend;
+};
+
 SourcesModel::SourcesModel(QObject* parent)
-    : QAbstractListModel(parent)
+    : KConcatenateRowsProxyModel(parent)
 {}
 
 SourcesModel::~SourcesModel() = default;
 
-QHash<int, QByteArray> SourcesModel::roleNames() const
-{
-    return { {SourceBackend, "sourceBackend"} };
-}
-
 SourcesModel* SourcesModel::global()
 {
     return s_sources;
 }
 
+QHash<int, QByteArray> SourcesModel::roleNames() const
+{
+    QHash<int, QByteArray> roles = KConcatenateRowsProxyModel::roleNames();
+    roles.insert(SourcesBackend, "sourcesBackend");
+    roles.insert(ResourcesBackend, "resourcesBackend");
+    return roles;
+}
+
 static bool ensureModel(const QList<QByteArray> &roles)
 {
-    static QList<QByteArray> required = {"sourcesBackend", "display", "checked"};
-    for (const auto &role: roles) {
+    static auto required = {"display", "checked"};
+    for (const auto &role: required) {
         if (!roles.contains(role))
             return false;
     }
@@ -54,41 +84,44 @@ static bool ensureModel(const QList<QByteArray> &roles)
 
 void SourcesModel::addSourcesBackend(AbstractSourcesBackend* sources)
 {
-    if (m_sources.contains(sources))
+    auto backend = qobject_cast<AbstractResourcesBackend*>(sources->parent());
+    auto b = addBackend(backend);
+    if (!b)
         return;
 
+    b->m_sources = sources;
     Q_ASSERT(ensureModel(sources->sources()->roleNames().values()));
+    auto m = sources->sources();
+    m->setProperty(DisplayName, backend->displayName());
+    addSourceModel(m);
+}
 
-    beginInsertRows(QModelIndex(), m_sources.size(), m_sources.size());
-    m_sources += sources;
-    endInsertRows();
-    emit sourcesChanged();
+
+SourceBackendModel* SourcesModel::addBackend(AbstractResourcesBackend* backend)
+{
+    Q_ASSERT(backend);
+    const auto inSourcesModel = "InSourcesModel";
+    if (backend->dynamicPropertyNames().contains(inSourcesModel))
+        return nullptr;
+    backend->setProperty(inSourcesModel, 1);
+
+    auto b = new SourceBackendModel(backend);
+    b->setProperty(DisplayName, backend->displayName());
+    addSourceModel(b);
+    return b;
 }
 
 QVariant SourcesModel::data(const QModelIndex& index, int role) const
 {
-    if(!index.isValid() || index.row()>=m_sources.count()) {
-        return QVariant();
+    if (!index.isValid()) return {};
+    else if (role == SourceNameRole) {
+        const auto sidx = mapToSource(index);
+        const auto model = sidx.model();
+        auto ret = model->property(DisplayName);
+        return ret;
+    } else {
+        return KConcatenateRowsProxyModel::data(index, role);
     }
-    switch(role) {
-        case SourceBackend:
-            return QVariant::fromValue<QObject*>(m_sources[index.row()]);
-    }
-
-    return QVariant();
 }
 
-int SourcesModel::rowCount(const QModelIndex& parent) const
-{
-    return parent.isValid() ? 0 : m_sources.count();
-}
-
-QList<QObject*> SourcesModel::actions() const
-{
-    QList<QObject*> ret;
-    for(AbstractSourcesBackend* b: m_sources) {
-        foreach(QAction* action, b->actions())
-            ret.append(action);
-    }
-    return ret;
-}
+#include "SourcesModel.moc"
